searchData={"items":[{"type":"module","title":"Inertia","doc":"The Inertia.js adapter for Elixir/Phoenix applications.","ref":"Inertia.html"},{"type":"module","title":"Inertia.Controller","doc":"Controller functions for rendering Inertia.js responses.","ref":"Inertia.Controller.html"},{"type":"function","title":"Inertia.Controller.assign_prop/3","doc":"Assigns a prop value to the Inertia page data.","ref":"Inertia.Controller.html#assign_prop/3"},{"type":"function","title":"Inertia.Controller.render_inertia/3","doc":"Renders an Inertia response.","ref":"Inertia.Controller.html#render_inertia/3"},{"type":"module","title":"Inertia.HTML","doc":"HTML components for Inertia views.","ref":"Inertia.HTML.html"},{"type":"function","title":"Inertia.HTML.inertia_page/1","doc":"","ref":"Inertia.HTML.html#inertia_page/1"},{"type":"function","title":"Attributes - Inertia.HTML.inertia_page/1","doc":"* `component` (`:string`) (required) - The name of the JavaScript page component.\n* `props` (`:map`) (required) - The page props (data).\n* `url` (`:string`) (required) - The page URL.\n* `version` (`:string`) (required) - The current asset version.","ref":"Inertia.HTML.html#inertia_page/1-attributes"},{"type":"function","title":"Inertia.HTML.inertia_title/1","doc":"","ref":"Inertia.HTML.html#inertia_title/1"},{"type":"function","title":"Attributes - Inertia.HTML.inertia_title/1","doc":"* `prefix` (`:string`) - A prefix added before the content of `inner_block`. Defaults to `nil`.\n* `suffix` (`:string`) - A suffix added after the content of `inner_block`. Defaults to `nil`.","ref":"Inertia.HTML.html#inertia_title/1-attributes"},{"type":"function","title":"Slots - Inertia.HTML.inertia_title/1","doc":"* `inner_block` (required) - Content rendered inside the `title` tag.","ref":"Inertia.HTML.html#inertia_title/1-slots"},{"type":"module","title":"Inertia.Plug","doc":"The plug module for detecting Inertia.js requests.","ref":"Inertia.Plug.html"},{"type":"function","title":"Inertia.Plug.call/2","doc":"","ref":"Inertia.Plug.html#call/2"},{"type":"function","title":"Inertia.Plug.init/1","doc":"","ref":"Inertia.Plug.html#init/1"},{"type":"extras","title":"Inertia.js Phoenix Adapter","doc":"# Inertia.js Phoenix Adapter [![Hex Docs](https://img.shields.io/hexpm/v/inertia)](https://hexdocs.pm/inertia/readme.html)\n\nAn Elixir/Phoenix adapter for [Inertia.js](https://inertiajs.com/).","ref":"readme.html"},{"type":"extras","title":"Installation - Inertia.js Phoenix Adapter","doc":"The package can be installed by adding `inertia` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:inertia, \"~> 0.1.0\"}\n  ]\nend\n```\n\nAdd your desired configuration in your `config.exs` file:\n\n```elixir\n# config/config.exs\n\nconfig :inertia,\n  # The Phoenix Endpoint module for your application. This is used for building\n  # asset URLs to compute a unique version hash to track when something has\n  # changed (and a reload is required on the frontend).\n  endpoint: MyAppWeb.Endpoint,\n\n  # An optional list of static file paths to track for changes. You'll generally\n  # want to include any JavaScript assets that may require a page refresh when\n  # modified.\n  static_paths: [\"/assets/app.js\"],\n\n  # The default version string to use (if you decide not to track any static\n  # assets using the `static_paths` config). Defaults to \"1\".\n  default_version: \"1\"\n```\n\nThis library includes a few modules to help render Inertia responses:\n\n- [`Inertia.Plug`](https://github.com/svycal/inertia-phoenix/blob/main/lib/inertia/plug.ex): a plug for detecting Inertia.js requests and preparing the connection accordingly.\n- [`Inertia.Controller`](https://github.com/svycal/inertia-phoenix/blob/main/lib/inertia/controller.ex): controller functions for rendering Inertia.js-compatible responses.\n- [`Inertia.HTML`](https://github.com/svycal/inertia-phoenix/blob/main/lib/inertia/html.ex): HTML components for Inertia-powered views.\n\nTo get started, import `Inertia.Controller` in your controller helper and `Inertia.HTML` in your html helper:\n\n```diff\n  # lib/my_app_web.ex\n  defmodule MyAppWeb do\n    def controller do\n      quote do\n        use Phoenix.Controller, namespace: MyAppWeb\n\n+       import Inertia.Controller\n      end\n    end\n\n    def html do\n      quote do\n        use Phoenix.Component\n\n+       import Inertia.HTML\n      end\n    end\n  end\n```\n\nThen, install the plug in your browser pipeline:\n\n```diff\n  # lib/my_app_web/router.ex\n  defmodule MyAppWeb.Router do\n    use MyAppWeb, :router\n\n    pipeline :browser do\n      plug :accepts, [\"html\"]\n\n+     plug Inertia.Plug\n    end\n  end\n```\n\nNext, replace the title tag in your layout with the ` ` component, so that the client-side library will keep the title in sync:\n\n```diff\n  # lib/my_app_web/components/layouts/root.html.heex\n   \n   \n     \n-        \n+        \n     \n```\n\nYou're now ready to start rendering inertia responses!","ref":"readme.html#installation"},{"type":"extras","title":"Rendering responses - Inertia.js Phoenix Adapter","doc":"Rendering an Inertia.js response looks like this:\n\n```elixir\ndefmodule MyAppWeb.ProfileController do\n  use MyAppWeb, :controller\n\n  def index(conn, _params) do\n    conn\n    |> assign_prop(:text, \"Hello world\")\n    |> render_inertia(\"ProfilePage\")\n  end\nend\n```\n\nThe `assign_prop` function allows you defined props that should be passed in to the component. The `render_inertia` function accepts the conn, the name of the component to render, and an optional map containing more initial props to pass to the page component.\n\nThis action will render an HTML page containing a ` ` element with the name of the component and the initial props, following Inertia.js conventions. On subsequent requests dispatched by the Inertia.js client library, this action will return a JSON response with the data necessary for rendering the page.\n\n---\n\nMaintained by the team at [SavvyCal](https://savvycal.com)","ref":"readme.html#rendering-responses"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.0 - Changelog","doc":"- Initial release","ref":"changelog.html#0-1-0"},{"type":"extras","title":"License","doc":"# License\n\nMIT License\n\nCopyright (c) 2024 SavvyCal, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}